# sc8pr

An educational programming package for [Python 3](https://www.python.org). Inspired by [Scratch](https://scratch.mit.edu) and [Processing](https://www.processing.org), **sc8pr**’s aim is to make it easy for new and experienced Python programmers to create animations, games, and other graphics-based programs.

![Screenshot](https://dmaccarthy.github.io/sc8pr/img/soccer.png)

**sc8pr 3** features include:
* a simple, event-driven approach to creating interactive animations
* sprite management
* physics-based collisions
* video effects / transitions
* a selection of GUI controls
* curve plotting
* robotics simulator

For more information, please see the [tutorial and reference](https://dmaccarthy.github.io/sc8pr/).

# Installation

Latest stable release (3.0) including extras with additional dependencies:
```
pip3 install sc8prx
```

Latest stable release (3.0), core features that depend only on **pygame**:
```
pip3 install sc8pr
```

Alternatively, you can download **sc8pr** from GitHub and run it from the source code. Ensure that **pygame 2** is installed!

See the documentation for more [detailed instructions](https://dmaccarthy.github.io/sc8pr/?inst).
